pub enum SparseError {
LengthMismatch {
indices: usize,
values: usize,
},
UnsortedIndices {
position: usize,
prev: u32,
curr: u32,
},
NonFiniteWeight {
position: usize,
value: f32,
},
Truncated {
need: usize,
got: usize,
},
TrailingBytes {
trailing: usize,
},
}Expand description
Errors produced by SparseVector construction, encoding, and decoding.
Variants
LengthMismatch
indices and values had different lengths.
UnsortedIndices
indices were not in strictly ascending order (which also forbids duplicates).
NonFiniteWeight
A weight was non-finite (NaN or ±infinity).
Truncated
An encoded buffer was too short to contain its declared payload.
TrailingBytes
An encoded buffer carried trailing bytes after its declared payload.